@@ -5,7 +5,7 @@ import sys
 from zipfile import ZIP_DEFLATED
 
 
-VERSION = '8.2.2'
+VERSION = '8.3.5'
 """Program version.
 
 This value is under control of the update process, as run by
@@ -36,7 +36,7 @@ See Also
 tf.clean
 """
 
-API_VERSION = 2
+API_VERSION = 3
 """TF API version.
 
 Text-Fabric offers and API to TF apps.
@@ -122,7 +122,7 @@ EXPRESS_SYNC_LEGACY = [
 
 PROTOCOL = "http://"
 HOST = "localhost"
-PORT_BASE = 8976
+PORT_BASE = 10000
 
 URL_TFDOC = f"https://{ORG}.github.io/{REPO}"
 """Base url of the online Text-Fabric documentation."""
@@ -151,6 +151,9 @@ APP_GITHUB = f"{GH_BASE}/annotation"
 APP_CONFIG = "config.yaml"
 """Name of the config file of a TF app."""
 
+APP_CONFIG_OLD = "config.py"
+"""Name of the config file of a an older, incompatible TF app."""
+
 APP_CODE = "code"
 """Name of the top-level directory of a TF app."""
 
