@@ -173,7 +173,7 @@ class Search(object):
     ):
         """Searches for combinations of nodes that together match a search template.
 
-        If you can, you should use `tf.applib.search.search` instead.
+        If you can, you should use `tf.advanced.search.search` instead.
 
         Parameters
         ----------
@@ -465,7 +465,7 @@ class Search(object):
             This
 
                 for result in S.fetch(limit=10):
-                    print(S.glean(result))
+                    TF.info(S.glean(result))
 
             is a handy way to get an impression of the first bunch of results.
 
@@ -475,7 +475,7 @@ class Search(object):
 
         !!! hint "More ways of showing results"
             The advanced API offers much better ways of showing results.
-            See `tf.applib.display.show` and `tf.applib.display.table`.
+            See `tf.advanced.display.show` and `tf.advanced.display.table`.
         """
 
         T = self.api.T
