@@ -10,11 +10,11 @@ import rpyc
 from rpyc.utils.server import ThreadedServer
 
 from ..core.helpers import console
-from ..applib.app import findApp
-from ..applib.highlight import getPassageHighlights
-from ..applib.search import runSearch, runSearchCondensed
-from ..applib.helpers import getResultsX
-from ..applib.tables import compose, composeP, composeT
+from ..advanced.app import findApp
+from ..advanced.highlight import getPassageHighlights
+from ..advanced.search import runSearch, runSearchCondensed
+from ..advanced.helpers import getResultsX
+from ..advanced.tables import compose, composeP, composeT
 
 from .command import argKernel
 
@@ -115,6 +115,8 @@ def makeTfKernel(app, appName, port):
             """Fetches the TF app context settings for the corpus.
             """
 
+            app = self.app
+
             return pickle.dumps(app.context)
 
         def exposed_passage(
@@ -161,7 +163,7 @@ def makeTfKernel(app, appName, port):
                 `getx` is the identifier (section label, verse number) of the item/
 
             options: dict
-                Additional, optional display options, see `tf.applib.displaysettings`.
+                Additional, optional display options, see `tf.advanced.options`.
             """
 
             app = self.app
@@ -280,7 +282,7 @@ def makeTfKernel(app, appName, port):
                 `getx` is the identifier (section label, verse number) of the item/
 
             options: dict
-                Additional, optional display options, see `tf.applib.displaysettings`.
+                Additional, optional display options, see `tf.advanced.options`.
             """
 
             app = self.app
@@ -356,7 +358,7 @@ def makeTfKernel(app, appName, port):
 
             app = self.app
             display = app.display
-            dContext = display.get(options)
+            dContext = display.distill(options)
             condensed = dContext.condensed
             condenseType = dContext.condenseType
 
@@ -414,7 +416,7 @@ def makeTfKernel(app, appName, port):
 
             app = self.app
             display = app.display
-            dContext = display.get(options)
+            dContext = display.distill(options)
             fmt = dContext.fmt
             condensed = dContext.condensed
             condenseType = dContext.condenseType
@@ -517,16 +519,16 @@ def main(cargs=sys.argv):
     if checkout is None:
         checkout = ""
 
-    console(f"Setting up TF kernel for {appName} {moduleRefs} {setFile}")
+    console(f"Setting up TF kernel for {appName} {moduleRefs or ''} {setFile or ''}")
     app = findApp(
         appName,
         checkoutApp,
+        True,
         checkout=checkout,
         mod=moduleRefs,
         locations=locations,
         modules=modules,
         setFile=setFile,
-        _browse=True,
     )
     if app is None:
         return
